@@ -18,8 +18,7 @@
 
 extern obs_websocket_vendor vendor;
 
-DownstreamKeyer::DownstreamKeyer(int channel, QString name, obs_view_t *v,
-				 get_transitions_callback_t gt, void *gtd)
+DownstreamKeyer::DownstreamKeyer(int channel, QString name, obs_view_t *v, get_transitions_callback_t gt, void *gtd)
 	: outputChannel(channel),
 	  transition(nullptr),
 	  showTransition(nullptr),
@@ -42,8 +41,7 @@ DownstreamKeyer::DownstreamKeyer(int channel, QString name, obs_view_t *v,
 	QSizePolicy sizePolicy6(QSizePolicy::Preferred, QSizePolicy::Expanding);
 	sizePolicy6.setHorizontalStretch(0);
 	sizePolicy6.setVerticalStretch(0);
-	sizePolicy6.setHeightForWidth(
-		scenesList->sizePolicy().hasHeightForWidth());
+	sizePolicy6.setHeightForWidth(scenesList->sizePolicy().hasHeightForWidth());
 	scenesList->setSizePolicy(sizePolicy6);
 	scenesList->setContextMenuPolicy(Qt::CustomContextMenu);
 	scenesList->setFrameShape(QFrame::NoFrame);
@@ -52,8 +50,7 @@ DownstreamKeyer::DownstreamKeyer(int channel, QString name, obs_view_t *v,
 	scenesList->setDragEnabled(true);
 	scenesList->setDragDropMode(QAbstractItemView::InternalMove);
 	scenesList->setDefaultDropAction(Qt::TargetMoveAction);
-	connect(scenesList, SIGNAL(itemSelectionChanged()), this,
-		SLOT(on_scenesList_itemSelectionChanged()));
+	connect(scenesList, SIGNAL(itemSelectionChanged()), this, SLOT(on_scenesList_itemSelectionChanged()));
 
 	layout->addWidget(scenesList);
 
@@ -65,18 +62,18 @@ DownstreamKeyer::DownstreamKeyer(int channel, QString name, obs_view_t *v,
 	auto actionAddScene = new QAction(this);
 	actionAddScene->setObjectName(QStringLiteral("actionAddScene"));
 	actionAddScene->setProperty("themeID", "addIconSmall");
+	actionAddScene->setProperty("class", "icon-plus");
 	actionAddScene->setText(QT_UTF8(obs_module_text("Add")));
-	connect(actionAddScene, SIGNAL(triggered()), this,
-		SLOT(on_actionAddScene_triggered()));
+	connect(actionAddScene, SIGNAL(triggered()), this, SLOT(on_actionAddScene_triggered()));
 	scenesToolbar->addAction(actionAddScene);
 
 	auto actionRemoveScene = new QAction(this);
 	actionRemoveScene->setObjectName(QStringLiteral("actionRemoveScene"));
 	actionRemoveScene->setShortcutContext(Qt::WidgetWithChildrenShortcut);
 	actionRemoveScene->setProperty("themeID", "removeIconSmall");
+	actionRemoveScene->setProperty("class", "icon-minus");
 	actionRemoveScene->setText(QT_UTF8(obs_module_text("Remove")));
-	connect(actionRemoveScene, SIGNAL(triggered()), this,
-		SLOT(on_actionRemoveScene_triggered()));
+	connect(actionRemoveScene, SIGNAL(triggered()), this, SLOT(on_actionRemoveScene_triggered()));
 	scenesToolbar->addAction(actionRemoveScene);
 
 	scenesToolbar->addSeparator();
@@ -84,17 +81,17 @@ DownstreamKeyer::DownstreamKeyer(int channel, QString name, obs_view_t *v,
 	auto actionSceneUp = new QAction(this);
 	actionSceneUp->setObjectName(QStringLiteral("actionSceneUp"));
 	actionSceneUp->setProperty("themeID", "upArrowIconSmall");
+	actionSceneUp->setProperty("class", "icon-up");
 	actionSceneUp->setText(QT_UTF8(obs_module_text("MoveUp")));
-	connect(actionSceneUp, SIGNAL(triggered()), this,
-		SLOT(on_actionSceneUp_triggered()));
+	connect(actionSceneUp, SIGNAL(triggered()), this, SLOT(on_actionSceneUp_triggered()));
 	scenesToolbar->addAction(actionSceneUp);
 
 	auto actionSceneDown = new QAction(this);
 	actionSceneDown->setObjectName(QStringLiteral("actionSceneDown"));
 	actionSceneDown->setProperty("themeID", "downArrowIconSmall");
+	actionSceneDown->setProperty("class", "icon-down");
 	actionSceneDown->setText(QT_UTF8(obs_module_text("MoveDown")));
-	connect(actionSceneDown, SIGNAL(triggered()), this,
-		SLOT(on_actionSceneDown_triggered()));
+	connect(actionSceneDown, SIGNAL(triggered()), this, SLOT(on_actionSceneDown_triggered()));
 	scenesToolbar->addAction(actionSceneDown);
 
 	scenesToolbar->addSeparator();
@@ -102,9 +99,9 @@ DownstreamKeyer::DownstreamKeyer(int channel, QString name, obs_view_t *v,
 	auto actionSceneNull = new QAction(this);
 	actionSceneNull->setObjectName(QStringLiteral("actionSceneNull"));
 	actionSceneNull->setProperty("themeID", "pauseIconSmall");
+	actionSceneNull->setProperty("class", "icon-media-pause");
 	actionSceneNull->setText(QT_UTF8(obs_module_text("None")));
-	connect(actionSceneNull, SIGNAL(triggered()), this,
-		SLOT(on_actionSceneNull_triggered()));
+	connect(actionSceneNull, SIGNAL(triggered()), this, SLOT(on_actionSceneNull_triggered()));
 	scenesToolbar->addAction(actionSceneNull);
 
 	scenesToolbar->addSeparator();
@@ -125,8 +122,7 @@ DownstreamKeyer::DownstreamKeyer(int channel, QString name, obs_view_t *v,
 
 	layout->addWidget(scenesToolbar);
 
-	layout->addItem(new QSpacerItem(150, 0, QSizePolicy::Fixed,
-					QSizePolicy::Minimum));
+	layout->addItem(new QSpacerItem(150, 0, QSizePolicy::Fixed, QSizePolicy::Minimum));
 
 	const auto sh = obs_get_signal_handler();
 	signal_handler_connect(sh, "source_rename", source_rename, this);
@@ -137,9 +133,8 @@ DownstreamKeyer::DownstreamKeyer(int channel, QString name, obs_view_t *v,
 	disableDskHotkeyName += " ";
 	disableDskHotkeyName += name;
 
-	null_hotkey_id = obs_hotkey_register_frontend(
-		QT_TO_UTF8(disableDskHotkeyName),
-		QT_TO_UTF8(disableDskHotkeyName), null_hotkey, this);
+	null_hotkey_id =
+		obs_hotkey_register_frontend(QT_TO_UTF8(disableDskHotkeyName), QT_TO_UTF8(disableDskHotkeyName), null_hotkey, this);
 	QString enableTieHotkeyName = QT_UTF8(obs_module_text("EnableTie"));
 	enableTieHotkeyName += " ";
 	enableTieHotkeyName += name;
@@ -147,12 +142,14 @@ DownstreamKeyer::DownstreamKeyer(int channel, QString name, obs_view_t *v,
 	disableTieHotkeyName += " ";
 	disableTieHotkeyName += name;
 
-	tie_hotkey_id = obs_hotkey_pair_register_frontend(
-		QT_TO_UTF8(enableTieHotkeyName),
-		QT_TO_UTF8(enableTieHotkeyName),
-		QT_TO_UTF8(disableTieHotkeyName),
-		QT_TO_UTF8(disableTieHotkeyName), enable_tie_hotkey,
-		disable_tie_hotkey, this, this);
+	tie_hotkey_id = obs_hotkey_pair_register_frontend(QT_TO_UTF8(enableTieHotkeyName), QT_TO_UTF8(enableTieHotkeyName),
+							  QT_TO_UTF8(disableTieHotkeyName), QT_TO_UTF8(disableTieHotkeyName),
+							  enable_tie_hotkey, disable_tie_hotkey, this, this);
+
+	connect(&hideTimer, &QTimer::timeout, [this]() {
+		hideTimer.stop();
+		on_actionSceneNull_triggered();
+	});
 }
 
 DownstreamKeyer::~DownstreamKeyer()
@@ -203,10 +200,8 @@ void DownstreamKeyer::on_actionAddScene_triggered()
 	obs_source_t *scene = nullptr;
 	if (view) {
 		obs_source_t *source = obs_view_get_source(view, 0);
-		if (source &&
-		    obs_source_get_type(source) == OBS_SOURCE_TYPE_TRANSITION) {
-			obs_source_t *ts =
-				obs_transition_get_active_source(source);
+		if (source && obs_source_get_type(source) == OBS_SOURCE_TYPE_TRANSITION) {
+			obs_source_t *ts = obs_transition_get_active_source(source);
 			if (ts) {
 				obs_source_release(source);
 				source = ts;
@@ -218,15 +213,13 @@ void DownstreamKeyer::on_actionAddScene_triggered()
 			obs_source_release(source);
 		}
 	} else {
-		scene = obs_frontend_preview_program_mode_active()
-				? obs_frontend_get_current_preview_scene()
-				: obs_frontend_get_current_scene();
+		scene = obs_frontend_preview_program_mode_active() ? obs_frontend_get_current_preview_scene()
+								   : obs_frontend_get_current_scene();
 	}
 	if (!scene)
 		return;
 	auto sceneName = QT_UTF8(obs_source_get_name(scene));
-	if (scenesList->findItems(sceneName, Qt::MatchFixedString).count() ==
-	    0) {
+	if (scenesList->findItems(sceneName, Qt::MatchFixedString).count() == 0) {
 		add_scene(sceneName, scene);
 	}
 
@@ -264,12 +257,14 @@ void DownstreamKeyer::on_actionSceneNull_triggered()
 
 void DownstreamKeyer::apply_source(obs_source_t *const newSource)
 {
-	obs_source_t *prevSource =
-		view ? obs_view_get_source(view, outputChannel)
-		     : obs_get_output_source(outputChannel);
+	if (newSource && hideAfter > 0) {
+		hideTimer.stop();
+		hideTimer.setInterval(hideAfter);
+		hideTimer.start();
+	}
+	obs_source_t *prevSource = view ? obs_view_get_source(view, outputChannel) : obs_get_output_source(outputChannel);
 	obs_source_t *prevTransition = nullptr;
-	if (prevSource &&
-	    obs_source_get_type(prevSource) == OBS_SOURCE_TYPE_TRANSITION) {
+	if (prevSource && obs_source_get_type(prevSource) == OBS_SOURCE_TYPE_TRANSITION) {
 		prevTransition = prevSource;
 		prevSource = obs_transition_get_active_source(prevSource);
 	}
@@ -285,16 +280,12 @@ void DownstreamKeyer::apply_source(obs_source_t *const newSource)
 	} else {
 		auto ph = obs_get_proc_handler();
 		calldata_t cd = {0};
-		calldata_set_string(&cd, "from_scene",
-				    obs_source_get_name(prevSource));
-		calldata_set_string(&cd, "to_scene",
-				    obs_source_get_name(newSource));
-		if (proc_handler_call(ph, "get_transition_table_transition",
-				      &cd)) {
+		calldata_set_string(&cd, "from_scene", obs_source_get_name(prevSource));
+		calldata_set_string(&cd, "to_scene", obs_source_get_name(newSource));
+		if (proc_handler_call(ph, "get_transition_table_transition", &cd)) {
 			const char *p = calldata_string(&cd, "transition");
 			SetTransition(p ? p : "", transitionType::override);
-			SetTransitionDuration(calldata_int(&cd, "duration"),
-					      transitionType::override);
+			SetTransitionDuration(calldata_int(&cd, "duration"), transitionType::override);
 		} else {
 			SetTransition("", transitionType::override);
 		}
@@ -310,43 +301,30 @@ void DownstreamKeyer::apply_source(obs_source_t *const newSource)
 	} else {
 		if (!newTransition) {
 			if (view) {
-				obs_view_set_source(view, outputChannel,
-						    newSource);
+				obs_view_set_source(view, outputChannel, newSource);
 			} else {
 				obs_set_output_source(outputChannel, newSource);
 			}
 		} else {
 			obs_transition_set(newTransition, prevSource);
 
-			obs_transition_start(newTransition,
-					     OBS_TRANSITION_MODE_AUTO,
-					     newTransitionDuration, newSource);
+			obs_transition_start(newTransition, OBS_TRANSITION_MODE_AUTO, newTransitionDuration, newSource);
 
 			if (prevTransition != newTransition) {
 				if (view) {
-					obs_view_set_source(view, outputChannel,
-							    newTransition);
+					obs_view_set_source(view, outputChannel, newTransition);
 				} else {
-					obs_set_output_source(outputChannel,
-							      newTransition);
+					obs_set_output_source(outputChannel, newTransition);
 				}
 			}
 		}
 		if (vendor) {
 			const auto data = obs_data_create();
-			obs_data_set_string(data, "dsk_name",
-					    QT_TO_UTF8(objectName()));
+			obs_data_set_string(data, "dsk_name", QT_TO_UTF8(objectName()));
 			obs_data_set_int(data, "dsk_channel", outputChannel);
-			obs_data_set_string(
-				data, "new_scene",
-				newSource ? obs_source_get_name(newSource)
-					  : "");
-			obs_data_set_string(
-				data, "old_scene",
-				prevSource ? obs_source_get_name(prevSource)
-					   : "");
-			obs_websocket_vendor_emit_event(
-				vendor, "dsk_scene_changed", data);
+			obs_data_set_string(data, "new_scene", newSource ? obs_source_get_name(newSource) : "");
+			obs_data_set_string(data, "old_scene", prevSource ? obs_source_get_name(prevSource) : "");
+			obs_websocket_vendor_emit_event(vendor, "dsk_scene_changed", data);
 			obs_data_release(data);
 		}
 	}
@@ -358,10 +336,7 @@ void DownstreamKeyer::apply_source(obs_source_t *const newSource)
 void DownstreamKeyer::apply_selected_source()
 {
 	const auto l = scenesList->selectedItems();
-	const auto newSource =
-		l.count()
-			? obs_get_source_by_name(QT_TO_UTF8(l.value(0)->text()))
-			: nullptr;
+	const auto newSource = l.count() ? obs_get_source_by_name(QT_TO_UTF8(l.value(0)->text())) : nullptr;
 
 	apply_source(newSource);
 	obs_source_release(newSource);
@@ -375,8 +350,7 @@ void DownstreamKeyer::on_scenesList_itemSelectionChanged()
 	apply_selected_source();
 }
 
-void DownstreamKeyer::ChangeSceneIndex(bool relative, int offset,
-				       int invalidIdx)
+void DownstreamKeyer::ChangeSceneIndex(bool relative, int offset, int invalidIdx)
 {
 	int idx = scenesList->currentRow();
 	if (idx == -1 || idx == invalidIdx)
@@ -396,36 +370,26 @@ void DownstreamKeyer::ChangeSceneIndex(bool relative, int offset,
 
 void DownstreamKeyer::Save(obs_data_t *data)
 {
-	obs_data_set_string(data, "transition",
-			    transition ? obs_source_get_name(transition) : "");
+	obs_data_set_string(data, "transition", transition ? obs_source_get_name(transition) : "");
 	obs_data_set_int(data, "transition_duration", transitionDuration);
-	obs_data_set_string(data, "show_transition",
-			    showTransition ? obs_source_get_name(showTransition)
-					   : "");
-	obs_data_set_int(data, "show_transition_duration",
-			 showTransitionDuration);
-	obs_data_set_string(data, "hide_transition",
-			    hideTransition ? obs_source_get_name(hideTransition)
-					   : "");
-	obs_data_set_int(data, "hide_transition_duration",
-			 hideTransitionDuration);
+	obs_data_set_string(data, "show_transition", showTransition ? obs_source_get_name(showTransition) : "");
+	obs_data_set_int(data, "show_transition_duration", showTransitionDuration);
+	obs_data_set_string(data, "hide_transition", hideTransition ? obs_source_get_name(hideTransition) : "");
+	obs_data_set_int(data, "hide_transition_duration", hideTransitionDuration);
+	obs_data_set_int(data, "hide_after", hideAfter);
+	obs_data_set_bool(data, "tie", tie->isChecked());
 	obs_data_array_t *sceneArray = obs_data_array_create();
 	for (int i = 0; i < scenesList->count(); i++) {
 		auto item = scenesList->item(i);
 		if (!item)
 			continue;
 		auto sceneData = obs_data_create();
-		obs_data_set_string(sceneData, "name",
-				    QT_TO_UTF8(item->text()));
+		obs_data_set_string(sceneData, "name", QT_TO_UTF8(item->text()));
 		obs_data_array_push_back(sceneArray, sceneData);
 		obs_data_release(sceneData);
 	}
 	obs_data_set_array(data, "scenes", sceneArray);
-	obs_data_set_string(
-		data, "scene",
-		scenesList->currentItem()
-			? QT_TO_UTF8(scenesList->currentItem()->text())
-			: "");
+	obs_data_set_string(data, "scene", scenesList->currentItem() ? QT_TO_UTF8(scenesList->currentItem()->text()) : "");
 	obs_data_array_release(sceneArray);
 
 	obs_data_array_t *nh = obs_hotkey_save(null_hotkey_id);
@@ -462,8 +426,7 @@ std::string DownstreamKeyer::GetTransition(enum transitionType transition_type)
 	return "";
 }
 
-void DownstreamKeyer::SetTransition(const char *transition_name,
-				    enum transitionType transition_type)
+void DownstreamKeyer::SetTransition(const char *transition_name, enum transitionType transition_type)
 {
 	obs_source_t *oldTransition = transition;
 	if (transition_type == transitionType::show)
@@ -480,16 +443,12 @@ void DownstreamKeyer::SetTransition(const char *transition_name,
 	obs_frontend_source_list transitions = {};
 	get_transitions(get_transitions_data, &transitions);
 	for (size_t i = 0; i < transitions.sources.num; i++) {
-		const char *n =
-			obs_source_get_name(transitions.sources.array[i]);
+		const char *n = obs_source_get_name(transitions.sources.array[i]);
 		if (!n)
 			continue;
 		if (strcmp(transition_name, n) == 0) {
-			newTransition = obs_source_duplicate(
-				transitions.sources.array[i],
-				obs_source_get_name(
-					transitions.sources.array[i]),
-				true);
+			newTransition = obs_source_duplicate(transitions.sources.array[i],
+							     obs_source_get_name(transitions.sources.array[i]), true);
 			break;
 		}
 	}
@@ -503,41 +462,32 @@ void DownstreamKeyer::SetTransition(const char *transition_name,
 		overrideTransition = newTransition;
 	else
 		transition = newTransition;
-	obs_source_t *prevSource =
-		view ? obs_view_get_source(view, outputChannel)
-		     : obs_get_output_source(outputChannel);
+	obs_source_t *prevSource = view ? obs_view_get_source(view, outputChannel) : obs_get_output_source(outputChannel);
 	if (oldTransition && prevSource == oldTransition) {
 		if (newTransition) {
 			//swap transition
 			obs_transition_swap_begin(newTransition, oldTransition);
 			if (view) {
-				obs_view_set_source(view, outputChannel,
-						    newTransition);
+				obs_view_set_source(view, outputChannel, newTransition);
 			} else {
-				obs_set_output_source(outputChannel,
-						      newTransition);
+				obs_set_output_source(outputChannel, newTransition);
 			}
 			obs_transition_swap_end(newTransition, oldTransition);
 		} else {
 			auto item = scenesList->currentItem();
 			if (item) {
-				auto scene = obs_get_source_by_name(
-					QT_TO_UTF8(item->text()));
+				auto scene = obs_get_source_by_name(QT_TO_UTF8(item->text()));
 				if (view) {
-					obs_view_set_source(view, outputChannel,
-							    scene);
+					obs_view_set_source(view, outputChannel, scene);
 				} else {
-					obs_set_output_source(outputChannel,
-							      scene);
+					obs_set_output_source(outputChannel, scene);
 				}
 				obs_source_release(scene);
 			} else {
 				if (view) {
-					obs_view_set_source(view, outputChannel,
-							    nullptr);
+					obs_view_set_source(view, outputChannel, nullptr);
 				} else {
-					obs_set_output_source(outputChannel,
-							      nullptr);
+					obs_set_output_source(outputChannel, nullptr);
 				}
 			}
 		}
@@ -549,8 +499,7 @@ void DownstreamKeyer::SetTransition(const char *transition_name,
 	}
 }
 
-void DownstreamKeyer::SetTransitionDuration(int duration,
-					    enum transitionType transition_type)
+void DownstreamKeyer::SetTransitionDuration(int duration, enum transitionType transition_type)
 {
 	if (transition_type == match)
 		transitionDuration = duration;
@@ -573,6 +522,18 @@ int DownstreamKeyer::GetTransitionDuration(enum transitionType transition_type)
 	return transitionDuration;
 }
 
+void DownstreamKeyer::SetHideAfter(int duration)
+{
+	hideAfter = duration;
+	if (duration == 0)
+		hideTimer.stop();
+}
+
+int DownstreamKeyer::GetHideAfter()
+{
+	return hideAfter;
+}
+
 void DownstreamKeyer::SceneChanged(std::string scene)
 {
 	auto found = false;
@@ -585,14 +546,10 @@ void DownstreamKeyer::SceneChanged(std::string scene)
 		apply_source(nullptr);
 		return;
 	} else {
-		obs_source_t *prevSource =
-			view ? obs_view_get_source(view, outputChannel)
-			     : obs_get_output_source(outputChannel);
-		if (prevSource && obs_source_get_type(prevSource) ==
-					  OBS_SOURCE_TYPE_TRANSITION) {
+		obs_source_t *prevSource = view ? obs_view_get_source(view, outputChannel) : obs_get_output_source(outputChannel);
+		if (prevSource && obs_source_get_type(prevSource) == OBS_SOURCE_TYPE_TRANSITION) {
 			obs_source_t *prevTransition = prevSource;
-			prevSource = obs_transition_get_active_source(
-				prevTransition);
+			prevSource = obs_transition_get_active_source(prevTransition);
 			obs_source_release(prevTransition);
 		}
 		if (prevSource == nullptr) {
@@ -612,38 +569,29 @@ void DownstreamKeyer::Load(obs_data_t *data)
 {
 	SetTransition(obs_data_get_string(data, "transition"));
 	transitionDuration = obs_data_get_int(data, "transition_duration");
-	SetTransition(obs_data_get_string(data, "show_transition"),
-		      transitionType::show);
-	showTransitionDuration =
-		obs_data_get_int(data, "show_transition_duration");
-	SetTransition(obs_data_get_string(data, "hide_transition"),
-		      transitionType::hide);
-	hideTransitionDuration =
-		obs_data_get_int(data, "hide_transition_duration");
+	SetTransition(obs_data_get_string(data, "show_transition"), transitionType::show);
+	showTransitionDuration = obs_data_get_int(data, "show_transition_duration");
+	SetTransition(obs_data_get_string(data, "hide_transition"), transitionType::hide);
+	hideTransitionDuration = obs_data_get_int(data, "hide_transition_duration");
+	hideAfter = obs_data_get_int(data, "hide_after");
+	tie->setChecked(obs_data_get_bool(data, "tie"));
 	scenesList->clear();
 	obs_data_array_t *sceneArray = obs_data_get_array(data, "scenes");
 	const auto sceneName = QT_UTF8(obs_data_get_string(data, "scene"));
 	if (sceneArray) {
 		auto count = obs_data_array_count(sceneArray);
 		for (size_t i = 0; i < count; i++) {
-			const auto sceneData =
-				obs_data_array_item(sceneArray, i);
-			const auto source_name =
-				obs_data_get_string(sceneData, "name");
-			const auto item =
-				new QListWidgetItem(QT_UTF8(source_name));
+			const auto sceneData = obs_data_array_item(sceneArray, i);
+			const auto source_name = obs_data_get_string(sceneData, "name");
+			const auto item = new QListWidgetItem(QT_UTF8(source_name));
 			scenesList->addItem(item);
-			obs_source_t *source =
-				obs_get_source_by_name(source_name);
+			obs_source_t *source = obs_get_source_by_name(source_name);
 			if (item->text() == sceneName) {
 				if (source) {
 					if (view) {
-						obs_view_set_source(
-							view, outputChannel,
-							source);
+						obs_view_set_source(view, outputChannel, source);
 					} else {
-						obs_set_output_source(
-							outputChannel, source);
+						obs_set_output_source(outputChannel, source);
 					}
 				}
 				scenesList->setCurrentItem(item);
@@ -652,25 +600,18 @@ void DownstreamKeyer::Load(obs_data_t *data)
 			obs_data_release(sceneData);
 
 			if (source) {
-				std::string enable_hotkey =
-					obs_module_text("EnableDSK");
+				std::string enable_hotkey = obs_module_text("EnableDSK");
 				enable_hotkey += " ";
 				enable_hotkey += QT_TO_UTF8(objectName());
-				std::string disable_hotkey =
-					obs_module_text("DisableDSK");
+				std::string disable_hotkey = obs_module_text("DisableDSK");
 				disable_hotkey += " ";
 				disable_hotkey += QT_TO_UTF8(objectName());
-				uint64_t h = obs_hotkey_pair_register_source(
-					source, enable_hotkey.c_str(),
-					enable_hotkey.c_str(),
-					disable_hotkey.c_str(),
-					disable_hotkey.c_str(),
-					enable_DSK_hotkey, disable_DSK_hotkey,
-					this, this);
+				uint64_t h = obs_hotkey_pair_register_source(source, enable_hotkey.c_str(), enable_hotkey.c_str(),
+									     disable_hotkey.c_str(), disable_hotkey.c_str(),
+									     enable_DSK_hotkey, disable_DSK_hotkey, this, this);
 
 				if (h != OBS_INVALID_HOTKEY_PAIR_ID) {
-					item->setData(Qt::UserRole,
-						      static_cast<uint>(h));
+					item->setData(Qt::UserRole, static_cast<uint>(h));
 				}
 				obs_source_release(source);
 			}
@@ -700,8 +641,7 @@ void DownstreamKeyer::Load(obs_data_t *data)
 		auto count = obs_data_array_count(excludes);
 		for (size_t i = 0; i < count; i++) {
 			const auto sceneData = obs_data_array_item(excludes, i);
-			exclude_scenes.emplace(
-				obs_data_get_string(sceneData, "name"));
+			exclude_scenes.emplace(obs_data_get_string(sceneData, "name"));
 			obs_data_release(sceneData);
 		}
 		obs_data_array_release(excludes);
@@ -724,23 +664,20 @@ void DownstreamKeyer::source_rename(void *data, calldata_t *calldata)
 void DownstreamKeyer::source_remove(void *data, calldata_t *calldata)
 {
 	const auto downstreamKeyer = static_cast<DownstreamKeyer *>(data);
-	const auto name = QT_UTF8(obs_source_get_name(
-		static_cast<obs_source_t *>(calldata_ptr(calldata, "source"))));
+	const auto name = QT_UTF8(obs_source_get_name(static_cast<obs_source_t *>(calldata_ptr(calldata, "source"))));
 
 	const auto count = downstreamKeyer->scenesList->count();
 	for (int i = count - 1; i >= 0; i--) {
 		const auto item = downstreamKeyer->scenesList->item(i);
 		if (item->text() == name) {
 			downstreamKeyer->scenesList->removeItemWidget(item);
-			obs_hotkey_pair_unregister(
-				item->data(Qt::UserRole).toUInt());
+			obs_hotkey_pair_unregister(item->data(Qt::UserRole).toUInt());
 			delete item;
 		}
 	}
 }
 
-bool DownstreamKeyer::enable_DSK_hotkey(void *data, obs_hotkey_pair_id id,
-					obs_hotkey_t *hotkey, bool pressed)
+bool DownstreamKeyer::enable_DSK_hotkey(void *data, obs_hotkey_pair_id id, obs_hotkey_t *hotkey, bool pressed)
 {
 	UNUSED_PARAMETER(hotkey);
 	if (!pressed)
@@ -761,8 +698,7 @@ bool DownstreamKeyer::enable_DSK_hotkey(void *data, obs_hotkey_pair_id id,
 	return changed;
 }
 
-bool DownstreamKeyer::disable_DSK_hotkey(void *data, obs_hotkey_pair_id id,
-					 obs_hotkey_t *hotkey, bool pressed)
+bool DownstreamKeyer::disable_DSK_hotkey(void *data, obs_hotkey_pair_id id, obs_hotkey_t *hotkey, bool pressed)
 {
 	UNUSED_PARAMETER(hotkey);
 	if (!pressed)
@@ -783,21 +719,17 @@ bool DownstreamKeyer::disable_DSK_hotkey(void *data, obs_hotkey_pair_id id,
 	return changed;
 }
 
-void DownstreamKeyer::null_hotkey(void *data, obs_hotkey_id id,
-				  obs_hotkey_t *hotkey, bool pressed)
+void DownstreamKeyer::null_hotkey(void *data, obs_hotkey_id id, obs_hotkey_t *hotkey, bool pressed)
 {
 	UNUSED_PARAMETER(id);
 	UNUSED_PARAMETER(hotkey);
 	if (!pressed)
 		return;
 	const auto downstreamKeyer = static_cast<DownstreamKeyer *>(data);
-	QMetaObject::invokeMethod(downstreamKeyer,
-				  "on_actionSceneNull_triggered",
-				  Qt::QueuedConnection);
+	QMetaObject::invokeMethod(downstreamKeyer, "on_actionSceneNull_triggered", Qt::QueuedConnection);
 }
 
-bool DownstreamKeyer::enable_tie_hotkey(void *data, obs_hotkey_pair_id id,
-					obs_hotkey_t *hotkey, bool pressed)
+bool DownstreamKeyer::enable_tie_hotkey(void *data, obs_hotkey_pair_id id, obs_hotkey_t *hotkey, bool pressed)
 {
 	UNUSED_PARAMETER(id);
 	UNUSED_PARAMETER(hotkey);
@@ -809,8 +741,7 @@ bool DownstreamKeyer::enable_tie_hotkey(void *data, obs_hotkey_pair_id id,
 	downstreamKeyer->tie->setChecked(true);
 	return true;
 }
-bool DownstreamKeyer::disable_tie_hotkey(void *data, obs_hotkey_pair_id id,
-					 obs_hotkey_t *hotkey, bool pressed)
+bool DownstreamKeyer::disable_tie_hotkey(void *data, obs_hotkey_pair_id id, obs_hotkey_t *hotkey, bool pressed)
 {
 	UNUSED_PARAMETER(id);
 	UNUSED_PARAMETER(hotkey);
@@ -831,10 +762,8 @@ void DownstreamKeyer::AddExcludeScene(const char *scene_name)
 	obs_source_t *scene = nullptr;
 	if (view) {
 		obs_source_t *source = obs_view_get_source(view, 0);
-		if (source &&
-		    obs_source_get_type(source) == OBS_SOURCE_TYPE_TRANSITION) {
-			obs_source_t *ts =
-				obs_transition_get_active_source(source);
+		if (source && obs_source_get_type(source) == OBS_SOURCE_TYPE_TRANSITION) {
+			obs_source_t *ts = obs_transition_get_active_source(source);
 			if (ts) {
 				obs_source_release(source);
 				source = ts;
@@ -860,10 +789,8 @@ void DownstreamKeyer::RemoveExcludeScene(const char *scene_name)
 	obs_source_t *scene = nullptr;
 	if (view) {
 		obs_source_t *source = obs_view_get_source(view, 0);
-		if (source &&
-		    obs_source_get_type(source) == OBS_SOURCE_TYPE_TRANSITION) {
-			obs_source_t *ts =
-				obs_transition_get_active_source(source);
+		if (source && obs_source_get_type(source) == OBS_SOURCE_TYPE_TRANSITION) {
+			obs_source_t *ts = obs_transition_get_active_source(source);
 			if (ts) {
 				obs_source_release(source);
 				source = ts;
@@ -918,10 +845,8 @@ void DownstreamKeyer::add_scene(QString scene_name, obs_source_t *s)
 	std::string disable_hotkey = obs_module_text("DisableDSK");
 	disable_hotkey += " ";
 	disable_hotkey += QT_TO_UTF8(objectName());
-	uint64_t h = obs_hotkey_pair_register_source(
-		s, enable_hotkey.c_str(), enable_hotkey.c_str(),
-		disable_hotkey.c_str(), disable_hotkey.c_str(),
-		enable_DSK_hotkey, disable_DSK_hotkey, this, this);
+	uint64_t h = obs_hotkey_pair_register_source(s, enable_hotkey.c_str(), enable_hotkey.c_str(), disable_hotkey.c_str(),
+						     disable_hotkey.c_str(), enable_DSK_hotkey, disable_DSK_hotkey, this, this);
 
 	if (h != OBS_INVALID_HOTKEY_PAIR_ID) {
 		item->setData(Qt::UserRole, static_cast<uint>(h));
@@ -933,8 +858,7 @@ bool DownstreamKeyer::AddScene(QString scene_name)
 	if (scene_name.isEmpty()) {
 		return false;
 	}
-	if (scenesList->findItems(scene_name, Qt::MatchFixedString).count() !=
-	    0) {
+	if (scenesList->findItems(scene_name, Qt::MatchFixedString).count() != 0) {
 		return true;
 	}
 	auto nameUtf8 = scene_name.toUtf8();
@@ -962,8 +886,7 @@ bool DownstreamKeyer::RemoveScene(QString scene_name)
 
 		if (item->text() == scene_name) {
 			scenesList->removeItemWidget(item);
-			obs_hotkey_pair_unregister(
-				item->data(Qt::UserRole).toUInt());
+			obs_hotkey_pair_unregister(item->data(Qt::UserRole).toUInt());
 			delete item;
 			return true;
 		}
@@ -980,23 +903,17 @@ void DownstreamKeyer::SetOutputChannel(int oc)
 {
 	if (oc == outputChannel)
 		return;
-	obs_source_t *prevSource =
-		view ? obs_view_get_source(view, outputChannel)
-		     : obs_get_output_source(outputChannel);
+	obs_source_t *prevSource = view ? obs_view_get_source(view, outputChannel) : obs_get_output_source(outputChannel);
 	obs_source_t *prevTransition = nullptr;
-	if (prevSource &&
-	    obs_source_get_type(prevSource) == OBS_SOURCE_TYPE_TRANSITION) {
+	if (prevSource && obs_source_get_type(prevSource) == OBS_SOURCE_TYPE_TRANSITION) {
 		prevTransition = prevSource;
 		prevSource = obs_transition_get_active_source(prevSource);
 	}
 	if (prevTransition) {
-		if (prevTransition == transition ||
-		    prevTransition == showTransition ||
-		    prevTransition == hideTransition ||
+		if (prevTransition == transition || prevTransition == showTransition || prevTransition == hideTransition ||
 		    prevTransition == overrideTransition) {
 			if (view) {
-				obs_view_set_source(view, outputChannel,
-						    nullptr);
+				obs_view_set_source(view, outputChannel, nullptr);
 			} else {
 				obs_set_output_source(outputChannel, nullptr);
 			}
@@ -1006,14 +923,10 @@ void DownstreamKeyer::SetOutputChannel(int oc)
 		}
 	} else if (prevSource) {
 		const auto l = scenesList->selectedItems();
-		const auto newSource =
-			l.count() ? obs_get_source_by_name(
-					    QT_TO_UTF8(l.value(0)->text()))
-				  : nullptr;
+		const auto newSource = l.count() ? obs_get_source_by_name(QT_TO_UTF8(l.value(0)->text())) : nullptr;
 		if (prevSource == newSource) {
 			if (view) {
-				obs_view_set_source(view, outputChannel,
-						    nullptr);
+				obs_view_set_source(view, outputChannel, nullptr);
 			} else {
 				obs_set_output_source(outputChannel, nullptr);
 			}
@@ -1026,8 +939,7 @@ void DownstreamKeyer::SetOutputChannel(int oc)
 	outputChannel = oc;
 	if (prevTransition) {
 		if (view) {
-			obs_view_set_source(view, outputChannel,
-					    prevTransition);
+			obs_view_set_source(view, outputChannel, prevTransition);
 		} else {
 			obs_set_output_source(outputChannel, prevTransition);
 		}
@@ -1041,6 +953,7 @@ void DownstreamKeyer::SetOutputChannel(int oc)
 LockedCheckBox::LockedCheckBox()
 {
 	setProperty("lockCheckBox", true);
+	setProperty("class", "indicator-lock");
 }
 
 LockedCheckBox::LockedCheckBox(QWidget *parent) : QCheckBox(parent) {}
